@@ -8,7 +8,7 @@ with 'CatalystX::DebugFilter';
 __PACKAGE__->mk_classdata('debug');
 __PACKAGE__->config(
 	'CatalystX::DebugFilter' => {
-		Request => { params => 'foo_param', headers => 'X-Secret' },
+		Request => { params => 'foo_param', headers => qr{X-Secret}i },
 		Response => { headers => [ qr{X-Res-Secret-2}i, sub { my ( $k, $v ) = @_; return $k eq 'X-Res-Secret-1' ? reverse($v) : undef  } ] }
 	}
 );
